clear all
global path ""
global data "$path/data"
global out "$path/out"
global other "$path/other"
global year "1995 1999 2002 2008 2010 2012 2014 2016 2018 2020" //全部样本年份
global year2 "2010 2012 2014 2016 2018 2020" //CFPS 年份
global asset "ta fa_n hs_n ot_n" //家庭净财富/金融资产/房产/其他资产


*==================================================================*
*基尼系数分解(结构和组群)
*==================================================================*
*==========================*
*1. 结构分解
*==========================*
use "CFPSCHIP.dta", clear
cd "$other"
foreach x in $year{
logout,save(`x'_1.xls) excel replace: descogini ta hs_n fa_n ot_n if year == `x' //房产——金融资产——其他资产
}
foreach x in $year2{
logout, save(`x'_2.xls) excel replace: descogini ta fa_n hs_a hs_s ot_n if year == `x' //房产增值——房产原值——金融资产——其他资产
}
foreach x in $year2{
logout, save(`x'_3.xls) excel replace: descogini ta hs_a ta_s if year == `x' //房产增值——自有收入积累
}
*数据汇总
foreach x in $year{ 
xmluse "`x'_1.xml",clear doctype(excel) sheet("Sheet1") allstring missing nocompress cells(A5:E8)
drop var2-var4
gen year =`x'
ren var1 class
format class %12s
ren var5 contribution
drop in 1/1
destring contribution,replace
gen type = 1
save "`x'_1.dta",replace
}
foreach x in $year2{ 
forval i = 2/3{
xmluse "`x'_`i'.xml",clear doctype(excel) sheet("Sheet1") allstring missing nocompress cells(A5:E9)
drop var2-var4
gen year =`x'
ren var1 class
format class %12s
ren var5 contribution
drop in 1/1
destring contribution,replace
drop if contribution == .
gen type = `i'
save "`x'_`i'.dta",replace
}
}
use "1995_1.dta",clear
foreach x in 1999 2002 2008 2010 2012 2014 2016 2018 2020{
append using "`x'_1.dta"
}
foreach x in $year2{ 
forval i = 2/3{
append using "`x'_`i'.dta"
}
}
order year type class contribution
reshape wide contribution,i(class year) j(type)
replace class=subinstr(class," ","",.) 
reshape wide contribution1-contribution3,i(year) j(class) string
keep year contribution1fan contribution1hsn contribution1otn ///
contribution2fan contribution2hsa contribution2hss contribution2otn ///
contribution3hsa  contribution3tas
order year contribution1fan contribution1hsn contribution1otn ///
contribution2fan contribution2hsa contribution2hss contribution2otn ///
contribution3hsa  contribution3tas
save "$out/基尼系数构成分解结果.dta",replace

*==========================*
*2. 组群分解
*==========================*
/************************
*1. 按照省份解总财富(删除单年度样本量小于30的样本)
************************/
use "$data/CFPSCHIP.dta", clear
drop if missing(ta)
bys year provcd: egen count = count(ta)
drop if count<30
drop count
foreach x in $year{
logout, save(`x') excel replace:ginidesc ta if year == `x',by(provcd)
}
foreach x in $year{
xmluse "`x'.xml",clear doctype(excel)  sheet("Sheet1") allstring missing nocompress cells(A7:C13)
drop in 1/2
drop in 4/4
gen year =`x'
ren var1 group
format group %12s
ren var3 contribution
drop var2
destring contribution,replace
save "`x'.dta",replace
}
use "1995.dta",clear
foreach x in 1999 2002 2008 2010 2012 2014 2016 2018 2020{
append using "`x'.dta"
}
order year group contribution
sort group year 
replace group="组间差距" if group =="Between"
replace group="组内差距" if group =="Within"
replace group="交叠项" if group =="Overlap"
drop if group == "Gini"
foreach x in contribution{
format `x' %9.2f
}
save "$other/gini_dec_group.dta",replace

/************************
*2. 按照区县解总财富(删除单年度样本量小于15的样本)
************************/
use "$data/CFPSCHIP.dta", clear
drop if missing(ta)
bys year county: egen count = count(ta)
drop if count<15
drop count
foreach x in $year{
logout , save(`x') excel replace:ginidesc ta if year == `x', by(county)
}
foreach x in $year{
xmluse "`x'.xml",clear doctype(excel)  sheet("Sheet1") allstring missing nocompress cells(A7:C13)
drop in 1/2
drop in 4/4
gen year =`x'
ren var1 group
format group %12s
ren var3 contribution
drop var2
destring contribution,replace
save "`x'.dta",replace
}

use "1995.dta",clear
foreach x in 1999 2002 2008 2010 2012 2014 2016 2018 2020{
append using "`x'.dta"
}
order year group contribution
sort group year 
replace group="组间差距" if group =="Between"
replace group="组内差距" if group =="Within"
replace group="交叠项" if group =="Overlap"
drop if group == "Gini"
foreach x in contribution{
format `x' %9.2f
}
save "$other/gini_dec_group2.dta",replace

/************************
*3. 按照有房-无房分解总财富
************************/
use "$data/CFPSCHIP.dta", clear
drop if missing(ta)
foreach x in $year{
logout, save(`x') excel replace:ginidesc ta if year == `x',by(hown)
}
foreach x in $year {
xmluse "`x'.xml",clear doctype(excel) sheet("Sheet1") allstring missing nocompress cells(A7:C13)
drop in 1/2
drop in 4/4
gen year =`x'
ren var1 group
format group %12s
ren var3 contribution
drop var2
destring contribution,replace force
save "`x'.dta",replace
}
use "1995.dta",clear
foreach x in 1999 2002 2008 2010 2012 2014 2016 2018 2020{
append using "`x'.dta"
}
order year group contribution
sort group year 
replace group="组间差距" if group =="Between"
replace group="组内差距" if group =="Within"
replace group="交叠项" if group =="Overlap"
drop if group == "Gini"
foreach x in contribution{
format `x' %9.2f
}
save "$other/gini_dec_group3.dta",replace

*==================================================================*
*基尼系数交叉分解
*==================================================================*
*==========================*
*1. 分项财富——省
*==========================*
foreach y in $asset{
use "$data/CFPSCHIP.dta", clear
drop if missing(`y')
bys year provcd : egen count = count(`y')
drop if count<30
drop count
foreach x in $year{
logout, save(`x'_`y') excel replace:ginidesc `y' if year == `x',by(provcd)
}
}
foreach y in $asset{
foreach x in $year{
xmluse "`x'_`y'.xml",clear doctype(excel) sheet("Sheet1") allstring missing nocompress cells(A9:C11)
gen year =`x'
gen class = "`y'"
ren var1 group
drop var2
format group %12s
ren var3 contribution
destring contribution,replace
save "`x'_`y'.dta",replace
}
}
foreach y in $asset{
use "1995_`y'.dta",clear
foreach x in $year{
append using "`x'_`y'.dta"
duplicates drop class year group,force
save "all_`y'.dta",replace
}
}
foreach x in Between Overlap Within{
use "all_hs_n.dta",clear
append using "all_fa_n.dta"
append using "all_ot_n.dta"
keep if group == "`x'"
ren contribution x
reshape wide x,i(class group) j(year)
save "`x'.dta",replace
}
use "Between.dta",clear
append using Overlap.dta
append using Within.dta
replace group = "1_Within" if group == "Within"
replace group = "2_Between" if group == "Between"
replace group = "3_Overlap" if group == "Overlap"
sort class group
save "$out/基尼系数构成按省份交叉分解_1.dta",replace
*==========================*
*2. 自有收入/房产增值——省
*==========================*
foreach x in hs_a ta_s{
use "$data/CFPSCHIP.dta", clear
drop if year < 2010
drop if missing(`x')
sort year `x'
bys year: egen t=sum(_n*`x')
bys year: egen s=sum(`x')
bys year: g gini_`x'=2*t/(_N*s)-1-1/_N //按年份生成基尼系数
drop t s
duplicates drop year,force
keep year gini_`x'
}
foreach y in hs_a ta_s{
use "$data/CFPSCHIP.dta", clear
drop if missing(`y')
bys year provcd : egen count = count(`y')
drop if count<30
drop count
foreach x in $year2{
logout, save(`x'_`y') excel replace:ginidesc `y' if year == `x',by(provcd)
}
}
foreach y in hs_a ta_s{
foreach x in $year2{
xmluse "`x'_`y'.xml",clear doctype(excel) sheet("Sheet1") allstring missing nocompress cells(A9:C11)
gen year =`x'
gen class = "`y'"
ren var1 group
drop var2
format group %12s
ren var3 contribution
destring contribution,replace
save "`x'_`y'.dta",replace
}
}
foreach y in hs_a ta_s{
use "2010_`y'.dta",clear
foreach x in $year2{
append using "`x'_`y'.dta"
duplicates drop class year group,force
save "all_`y'.dta",replace
}
}
foreach x in Between Overlap Within{
use "all_hs_a.dta",clear
append using "all_ta_s.dta"
keep if group == "`x'"
ren contribution x
reshape wide x,i(class group) j(year)
save "`x'.dta",replace
}
use "Between.dta",clear
append using Overlap.dta
append using Within.dta
replace group = "1_Within" if group == "Within"
replace group = "2_Between" if group == "Between"
replace group = "3_Overlap" if group == "Overlap"
sort class group
save "$out/基尼系数构成按省份交叉分解_2.dta",replace
*==========================*
*3. 有房/无房——省
*==========================*
forval i = 0/1{
use "$data/CFPSCHIP.dta", clear
keep if hown == `i'
drop if missing(ta)
sort year ta
bys year: egen t=sum(_n*ta)
bys year: egen s=sum(ta)
bys year: g gini_ta=2*t/(_N*s)-1-1/_N //按年份生成基尼系数
drop t s
duplicates drop year,force
keep year gini_ta
}
forval i = 0/1{
use "$data/CFPSCHIP.dta", clear
keep if hown == `i'
drop if missing(ta)
bys year provcd : egen count = count(ta)
drop if count<30
drop count
foreach x in $year{
logout, save(`x'_`i') excel replace:ginidesc ta if year == `x',by(provcd)
}
foreach x in $year{
xmluse "`x'_`i'.xml",clear doctype(excel)  sheet("Sheet1") allstring missing nocompress cells(A7:C11)
drop in 1/2
gen year =`x'
ren var1 group
format group %12s
ren var3 contribution
drop var2
destring contribution,replace
save "`x'_`i'.dta",replace
}
use "1995_`i'.dta",clear
foreach x in 1999 2002 2008 2010 2012 2014 2016 2018 2020{
append using "`x'_`i'.dta"
}
order year group contribution
sort group year 
gen hown = `i'
save "$merge/gini_dec_group_`i'.dta",replace
}
use "$merge/gini_dec_group_0.dta",clear
append using "$merge/gini_dec_group_1.dta"
ren contribution x
reshape wide x,i(hown group) j(year)
replace group = "1_Within" if group == "Within"
replace group = "2_Between" if group == "Between"
replace group = "3_Overlap" if group == "Overlap"
gsort -hown group
save "$out/基尼系数构成按省份交叉分解_3.dta",replace


*==================================================================*
*回归分析
*==================================================================*
global prov "prov_gdp prov_pop prov_gdpr2 prov_gdpr3" //省级控制变量
global household "y_edu health fti age age2 fsize" //家庭控制变量
*==================================================================*
*(一)描述性统计
*==================================================================*
cd "$out"
use "$data/proreg_ind.dta",clear
asdoc su $asset prov_pexp house_hold gini_county_pexp prov_exp_gap hs_a $household $prov, replace save(回归分析相关变量描述性统计_1.doc)
use "$data/proreg_prov.dta",clear
asdoc su gini_ta gini_ta_s gini_county_pexp gini_county_pfix gini_gl_inf gini_yizhan $prov, replace save(回归分析相关变量描述性统计_2.doc)

*==================================================================*
*(二)家庭面板数据回归
*==================================================================*
use "$data/proreg_ind.dta",clear
*==========================*
*1. 家庭财富的决定因素
*==========================*
use "$data/proreg_ind.dta",clear
eststo m1: reghdfe tap prov_pexp house_hold $household $prov, absorb(provcd year) cluster(hcode)
eststo m2: reghdfe hs_np prov_pexp house_hold $household $prov, absorb(provcd year) cluster(hcode)
eststo m3: reghdfe otp prov_pexp $household $prov, absorb(provcd year) cluster(hcode)
eststo m4: reghdfe ftip prov_pexp y_edu health age age2 fsize $prov, absorb(provcd year) cluster(hcode)
esttab m1 m2 m3 m4 using "$out/城镇家庭财富和收入的主导因素.rtf", replace b(%7.3f) se(%7.3f) ar2(%7.3f) star(* .10 ** .05 *** .01) mtitle() nogap drop(_cons )title()

*==========================*
*2. 分位数回归
*==========================*
eststo m1: qreg ta prov_pexp house_hold $household $prov i.provcd i.year, quantile(.1) vce(robust)
eststo m2: qreg ta prov_pexp house_hold $household $prov i.provcd i.year, quantile(.25) vce(robust)
eststo m3: qreg ta prov_pexp house_hold $household $prov i.provcd i.year, quantile(.5) vce(robust)
eststo m4: qreg ta prov_pexp house_hold $household $prov i.provcd i.year, quantile(.75) vce(robust)
eststo m5: qreg ta prov_pexp house_hold $household $prov i.provcd i.year, quantile(.9) vce(robust)
esttab m1 m2 m3 m4 m5 using "$out/城镇家庭净财富主导因素的分位数回归结果.rtf", replace b(%15.3f) se(%15.3f) ar2(%15.3f) star(* .10 ** .05 *** .01) mtitle() nogap drop($household $prov *.provcd *.year)title()

*==========================*
*3. RIF回归
*==========================*
eststo m1: rifhdreg ta gini_county_pexp prov_exp_gap hs_a $household $prov, rif(std) vce(robust) abs(provcd year) 
eststo m2: rifhdreg ta gini_county_pexp prov_exp_gap hs_a $household $prov, rif(cvar) vce(robust) abs(provcd year) 
eststo m3: rifhdreg ta gini_county_pexp prov_exp_gap hs_a $household $prov, rif(gini) vce(robust) abs(provcd year) 
eststo m4: rifhdreg hs_n gini_county_pexp prov_exp_gap hs_a $household $prov, rif(std) vce(robust) abs(provcd year) 
eststo m5: rifhdreg hs_n gini_county_pexp prov_exp_gap hs_a $household $prov, rif(cvar) vce(robust) abs(provcd year) 
eststo m6: rifhdreg hs_n gini_county_pexp prov_exp_gap hs_a $household $prov, rif(gini) vce(robust) abs(provcd year)  
esttab m1 m2 m3 m4 m5 m6 using "$out/城镇家庭净财富差距的RIF回归结果.rtf", replace b(%15.3f) se(%15.3f) ar2(%15.3f) star(* .10 ** .05 *** .01) mtitle() nogap drop(_cons $household $prov)title()

*==================================================================*
*(三)省级面板数据回归
*==================================================================*
use "$merge/proreg_prov.dta",clear
*==========================*
*1. Gini系数的决定因素
*==========================*
eststo m1:reghdfe gini_ta gini_county_pexp $prov,absorb(year provcd) cluster(provcd)
eststo m2:reghdfe gini_ta gini_county_pfix $prov,absorb(year provcd) cluster(provcd)
eststo m3:reghdfe gini_ta gini_gl_inf $prov,absorb(year provcd) cluster(provcd)
eststo m4:reghdfe gini_ta_s gini_county_pexp $prov,absorb(year provcd) cluster(provcd)
eststo m5:reghdfe gini_ta_s gini_county_pfix $prov,absorb(year provcd) cluster(provcd)
eststo m6:reghdfe gini_ta_s gini_gl_inf $prov,absorb(year provcd) cluster(provcd)
esttab m1 m2 m3 m4 m5 m6 using "$out/各省财富基尼系数与省内不同维度差距.rtf", replace b(%7.3f) se(%7.3f) ar2(%7.3f) star(* .10 ** .05 *** .01) mtitle() nogap drop(_cons $prov)title()
*==========================*
*2. 工具变量检验
*==========================*
eststo m1:ivregress 2sls gini_ta i.provcd i.year (gini_gl_inf = gini_yizhan),vce(cluster provcd) first
estat firststage
eststo m2:ivregress 2sls gini_ta $prov i.provcd i.year (gini_gl_inf = gini_yizhan),vce(cluster provcd) first
estat firststage
eststo m3:ivregress liml gini_ta $prov i.provcd i.year (gini_gl_inf = gini_yizhan),vce(cluster provcd) first
esttab m1 m2 m3 using "$out/各省财富基尼系数与省内不同维度差距（IV估计）.rtf", replace b(%7.3f) se(%7.3f) ar2(%7.3f) star(* .10 ** .05 *** .01) mtitle() nogap drop(_cons $prov *.provcd *.year)title()













